@@ -1,5 +1,8 @@
 package CatalystX::Resource::TraitFor::Controller::Resource::Create;
-$CatalystX::Resource::TraitFor::Controller::Resource::Create::VERSION = '0.009_002';
+{
+    $CatalystX::Resource::TraitFor::Controller::Resource::Create::VERSION = '0.002000';
+}
+
 use MooseX::MethodAttributes::Role;
 use namespace::autoclean;
 
@@ -9,8 +12,7 @@ requires qw/
     resultset_key
     resource_key
     form
-/;
-
+    /;
 
 has 'activate_fields_create' => (
     is      => 'ro',
@@ -18,8 +20,8 @@ has 'activate_fields_create' => (
     default => sub { [] },
 );
 
-
-sub create : Method('GET') Method('POST') Chained('base') PathPart('create') Args(0) {
+sub create : Method('GET') Method('POST') Chained('base') PathPart('create')
+    Args(0) {
     my ( $self, $c ) = @_;
     my $resource = $c->stash->{ $self->resultset_key }->new_result( {} );
     $c->stash(
@@ -32,26 +34,23 @@ sub create : Method('GET') Method('POST') Chained('base') PathPart('create') Arg
 1;
 
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 CatalystX::Resource::TraitFor::Controller::Resource::Create - a create action for your resource
 
 =head1 VERSION
 
-version 0.009_002
+version 0.002000
 
 =head1 ATTRIBUTES
 
 =head2 activate_fields_create
 
-(default = []).
-arrayref of form fields to activate in the create form
-(e.g. ['password', 'password_confirm'], default = [])
+hashref of form fields to activate in the create form
+e.g. ['password', 'password_confirm']
+default = []
 Can be overriden with $c->stash->{activate_form_fields}
 
 Example: You only want admins to be able to change a field.
@@ -75,3 +74,4 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
