@@ -1,5 +1,8 @@
 package CatalystX::Resource::TraitFor::Controller::Resource::Delete;
-$CatalystX::Resource::TraitFor::Controller::Resource::Delete::VERSION = '0.009_002';
+{
+    $CatalystX::Resource::TraitFor::Controller::Resource::Delete::VERSION = '0.002000';
+}
+
 use MooseX::MethodAttributes::Role;
 use namespace::autoclean;
 
@@ -9,10 +12,10 @@ requires qw/
     resource_key
     _msg
     _redirect
-/;
+    /;
 
-
-sub delete : Method('POST') Chained('base_with_id') PathPart('delete') Args(0) {
+sub delete : Method('POST') Chained('base_with_id') PathPart('delete')
+    Args(0) {
     my ( $self, $c ) = @_;
     my $resource = $c->stash->{ $self->resource_key };
     my $msg = $self->_msg( $c, 'delete' );
@@ -24,18 +27,15 @@ sub delete : Method('POST') Chained('base_with_id') PathPart('delete') Args(0) {
 1;
 
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 CatalystX::Resource::TraitFor::Controller::Resource::Delete - a delete action for your resource
 
 =head1 VERSION
 
-version 0.009_002
+version 0.002000
 
 =head1 ACTIONS
 
@@ -55,3 +55,4 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
