@@ -1,5 +1,8 @@
 package CatalystX::Resource::TraitFor::Controller::Resource::Edit;
-$CatalystX::Resource::TraitFor::Controller::Resource::Edit::VERSION = '0.009_002';
+{
+    $CatalystX::Resource::TraitFor::Controller::Resource::Edit::VERSION = '0.002000';
+}
+
 use MooseX::MethodAttributes::Role;
 use namespace::autoclean;
 
@@ -7,9 +10,7 @@ use namespace::autoclean;
 
 requires qw/
     form
-/;
-
-
+    /;
 
 has 'activate_fields_edit' => (
     is      => 'ro',
@@ -17,36 +18,32 @@ has 'activate_fields_edit' => (
     default => sub { [] },
 );
 
-
-sub edit : Method('GET') Method('POST') Chained('base_with_id') PathPart('edit') Args(0) {
+sub edit : Method('GET') Method('POST') Chained('base_with_id')
+    PathPart('edit') Args(0) {
     my ( $self, $c ) = @_;
     $c->stash( set_update_msg => 1 );
     $self->form( $c, $self->activate_fields_edit );
 }
 
-
 1;
 
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 CatalystX::Resource::TraitFor::Controller::Resource::Edit - a edit action for your resource
 
 =head1 VERSION
 
-version 0.009_002
+version 0.002000
 
 =head1 ATTRIBUTES
 
 =head2 activate_fields_edit
 
-arrayref of form fields to activate in the edit form
-(default = []).
+hashref of form fields to activate in the edit form
+default = []
 Can be overriden with $c->stash->{activate_form_fields}
 
 =head1 ACTIONS
@@ -67,3 +64,4 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
