@@ -1,5 +1,8 @@
 package CatalystX::Resource::TraitFor::Controller::Resource::Form;
-$CatalystX::Resource::TraitFor::Controller::Resource::Form::VERSION = '0.009_002';
+{
+    $CatalystX::Resource::TraitFor::Controller::Resource::Form::VERSION = '0.002000';
+}
+
 use MooseX::MethodAttributes::Role;
 use MooseX::Types::LoadableClass qw/ LoadableClass /;
 use namespace::autoclean;
@@ -10,46 +13,38 @@ requires qw/
     resource_key
     _msg
     _redirect
-/;
-
+    /;
 
 has 'form_class' => (
-    is       => 'rw',
+    is       => 'ro',
     required => 1,
     isa      => LoadableClass,
     coerce   => 1,
 );
 
-
 has 'form_template' => (
     is        => 'ro',
     predicate => 'has_form_template',
 );
 
-
 sub form {
     my ( $self, $c, $activate_fields ) = @_;
 
     my $resource = $c->stash->{ $self->resource_key };
 
     # activate_form_fields in stash overrides activate_fields from config
-    my $activate_form_fields =
-      exists $c->stash->{activate_form_fields}
-      ? $c->stash->{activate_form_fields}
-      : [@$activate_fields];
+    my $activate_form_fields = $c->stash->{activate_form_fields}
+        || [@$activate_fields];
 
-    my $form_attrs_new =
-      exists $c->stash->{form_attrs_new} ? $c->stash->{form_attrs_new} : {};
-    my $form_attrs_process =
-      exists $c->stash->{form_attrs_process} ? $c->stash->{form_attrs_process} : {};
+    # if you want to pass additional attributes to the form put a hashref in
+    # the stash key 'form_attrs'
+    my $form_attrs = $c->stash->{form_attrs} || {};
 
-    my $form = $self->form_class->new(%$form_attrs_new);
+    my $form = $self->form_class->new(%$form_attrs);
     $form->process(
         active => $activate_form_fields,
         item   => $resource,
         params => $c->req->params,
-        posted => ($c->req->method eq 'POST'),
-       %$form_attrs_process,
     );
 
     if ( $self->has_form_template ) {
@@ -72,23 +67,18 @@ sub form {
     $self->_redirect($c);
 }
 
-
-
 1;
 
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 CatalystX::Resource::TraitFor::Controller::Resource::Form - handles form related stuff
 
 =head1 VERSION
 
-version 0.009_002
+version 0.002000
 
 =head1 ATTRIBUTES
 
@@ -109,20 +99,6 @@ optional, if you don't supply a form_template a stringified version will be used
 handle form validation, configuration of visible fields
 and setting of notification messages
 
-=head1 Catalyst stash variables
-
-=head2 form_attrs_new
-
-you can pass attributes to $form->new via $c->stash->{form_attrs_new}
-
-  $c->stash->{form_attrs_new} = { #... };
-
-=head2 form_attrs_process
-
-you can pass attributes to $form->process via $c->stash->{form_attrs_process}
-
-  $c->stash->{form_attrs_process} = { posted => 0 };
-
 =head1 AUTHOR
 
 David Schmidt <davewood@cpan.org>
@@ -135,3 +111,4 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
