@@ -1,28 +1,37 @@
 package CatalystX::Resource::TraitFor::Controller::Resource::List;
-$CatalystX::Resource::TraitFor::Controller::Resource::List::VERSION = '0.009_002';
+{
+    $CatalystX::Resource::TraitFor::Controller::Resource::List::VERSION = '0.002000';
+}
+
 use MooseX::MethodAttributes::Role;
 use namespace::autoclean;
 
 # ABSTRACT: a list action for your resource
 
+requires qw/
+    resources_key
+    resultset_key
+    /;
 
-sub list : Method('GET') Chained('base') PathPart('list') Args(0) {}
+sub list : Method('GET') Chained('base') PathPart('list') Args(0) {
+    my ( $self, $c ) = @_;
+    $c->stash(
+        $self->resources_key => [ $c->stash->{ $self->resultset_key }->all ]
+    );
+}
 
 1;
 
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 CatalystX::Resource::TraitFor::Controller::Resource::List - a list action for your resource
 
 =head1 VERSION
 
-version 0.009_002
+version 0.002000
 
 =head1 ACTIONS
 
@@ -42,3 +51,4 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
