@@ -1,5 +1,8 @@
 package CatalystX::Resource::TraitFor::Controller::Resource::Sortable;
-$CatalystX::Resource::TraitFor::Controller::Resource::Sortable::VERSION = '0.009_002';
+{
+    $CatalystX::Resource::TraitFor::Controller::Resource::Sortable::VERSION = '0.002000';
+}
+
 use MooseX::MethodAttributes::Role;
 use namespace::autoclean;
 
@@ -9,65 +12,47 @@ requires qw/
     _msg
     resource_key
     _redirect
-/;
+    /;
 
 # ABSTRACT: make your Resource sortable
 
-
-sub move_next : Method('POST') Chained('base_with_id') PathPart('move_next') Args(0) {
+sub move_next : Method('POST') Chained('base_with_id') PathPart('move_next')
+    Args(0) {
     my ( $self, $c ) = @_;
     my $resource = $c->stash->{ $self->resource_key };
     $resource->move_next;
     $c->flash( msg => $self->_msg( $c, 'move_next' ) );
-    $c->res->redirect($c->req->referer || '/');
+    $self->_redirect($c);
 }
 
-
-sub move_previous : Method('POST') Chained('base_with_id') PathPart('move_previous') Args(0) {
+sub move_previous : Method('POST') Chained('base_with_id')
+    PathPart('move_previous') Args(0) {
     my ( $self, $c ) = @_;
     my $resource = $c->stash->{ $self->resource_key };
     $resource->move_previous;
     $c->flash( msg => $self->_msg( $c, 'move_previous' ) );
-    $c->res->redirect($c->req->referer || '/');
-}
-
-
-sub move_to : Method('POST') Chained('base_with_id') PathPart('move_to') Args(0) {
-    my ( $self, $c ) = @_;
-
-    my $pos = $c->req->param('pos');
-    if (!defined $pos) {
-        $c->stash( error_msg => $self->_msg( $c, 'move_to_undef' ) );
-        $c->detach( $self->error_path );
-    }
-
-    my $resource = $c->stash->{ $self->resource_key };
-    $resource->move_to( $pos );
-    $c->flash( msg => $self->_msg( $c, 'move_to' ) );
-    $c->res->redirect($c->req->referer || '/');
+    $self->_redirect($c);
 }
 
 1;
 
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 CatalystX::Resource::TraitFor::Controller::Resource::Sortable - makes your resource sortable
 
 =head1 VERSION
 
-version 0.009_002
+version 0.002000
 
 =head1 SYNOPSIS
 
     # TestApp.pm
     'Controller::Resource::Artist' => {
-        resultset_key => 'artists',
+        resultset_key => 'artists_rs',
+        resources_key => 'artists',
         resource_key => 'artist',
         form_class => 'TestApp::Form::Resource::Artist',
         model => 'DB::Resource::Artist',
@@ -112,9 +97,6 @@ Example: Artist has_many Albums has_many Songs
     # TestApp/Schema/Result/Resource/Song.pm
     __PACKAGE__->grouping_column('album_id');
 
-After a move operation you will always be redirected to the referer
-If no referer header is foudn you'll be redirected to '/'
-
 =head1 ACTIONS
 
 =head2 move_next
@@ -125,10 +107,6 @@ If no referer header is foudn you'll be redirected to '/'
 
     will switch the resource with the previous one
 
-=head2 move_to
-
-    move resource to denoted position
-
 =head1 AUTHOR
 
 David Schmidt <davewood@cpan.org>
@@ -141,3 +119,4 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
